from setuptools import setup, find_packages

setup(
    name="mezoAgent",
    version="0.1.4",
    packages=find_packages(),
    install_requires=[
        "web3",
        "langchain",
        "langchain-openai",
        "python-dotenv"
    ],
    description="A LangChain based tool kit for AI Agents to send BTC and mUSD transactions on Mezo Matsnet.",
    author="Dreadwulf",
    author_email="dreadwul@wtf.com",
    python_requires=">=3.7",
)